@@ -1,7 +1,7 @@
 import datetime 
 from SeasObjects.model.Evaluation import Evaluation
 from SeasObjects.model.Activity import Activity
-from SeasObjects.common.CLASS import CLASS
+from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.common.Tools import Tools
 from SeasObjects.seasexceptions.InsufficientDataException import InsufficientDataException
 import traceback
@@ -23,14 +23,14 @@ class CommandFactory(object):
 		# timestamp of when this message is being generated (now)
 		evaluation.setGeneratedAt(datetime.datetime.now())
 
-		evaluation.addType(CLASS.SEAS_COMMAND)
+		evaluation.addType(RESOURCE.SEAS_COMMAND)
 		
 		return evaluation;
 
 	
 	def fromString(self, data, serialization):
 		try:
-			return Evaluation().parse(Tools().getResourceByType(CLASS.SEAS_COMMAND, Tools().fromString(data, serialization)))
+			return Evaluation().parse(Tools().getResourceByType(RESOURCE.SEAS_COMMAND, Tools().fromString(data, serialization)))
 		except:
 			print "Unable to parse Evaluation by type seas:Command from the given string."
 			traceback.print_exc()
