@@ -1,5 +1,5 @@
 import datetime
-from SeasObjects.common.CLASS import CLASS
+from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.common.Tools import Tools
 from SeasObjects.model.Activity import Activity
 from SeasObjects.model.Notification import Notification
@@ -23,13 +23,13 @@ class NotificationFactory(object):
 
 		# timestamp of when this message is being generated (now)
 		notification.setGeneratedAt(datetime.datetime.now())
-		notification.addType(CLASS.SEAS_NOTIFICATION)
+		notification.addType(RESOURCE.SEAS_NOTIFICATION)
 
 		return notification
 
 	def fromString(self, data, serialization):
 		try:
-			return Notification().parse(Tools().getResourceByType(CLASS.SEAS_NOTIFICATION, Tools().fromString(data, serialization)))
+			return Notification().parse(Tools().getResourceByType(RESOURCE.SEAS_NOTIFICATION, Tools().fromString(data, serialization)))
 		except:
 			print "Unable to parse Evaluation by type seas:Notification from the given string."
 			traceback.print_exc()
