@@ -1,7 +1,7 @@
 from SeasObjects.model.Response import Response
 from SeasObjects.model.Activity import Activity
 from SeasObjects.common.Tools import Tools
-from SeasObjects.common.CLASS import CLASS
+from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.seasexceptions.InsufficientDataException import InsufficientDataException
 
 import datetime
@@ -24,14 +24,14 @@ class ResponseFactory(object):
 		# timestamp of when this message is being generated (now)
 		resp.setGeneratedAt(datetime.datetime.now())
 
-		resp.addType(CLASS.SEAS_RESPONSE)
+		resp.addType(RESOURCE.SEAS_RESPONSE)
 		
 		return resp
 
 	
 	def fromString(self, data, serialization):
 		try :
-			return Response().parse(Tools().getResourceByType(CLASS.SEAS_RESPONSE, Tools().fromString(data, serialization)));
+			return Response().parse(Tools().getResourceByType(RESOURCE.SEAS_RESPONSE, Tools().fromString(data, serialization)));
 		except:
 			print "Unable to parse Response by type seas:Response from the given string."
 			traceback.print_exc()
