@@ -1,5 +1,5 @@
 from SeasObjects.common.PROPERTY import PROPERTY
-from SeasObjects.common.CLASS import CLASS
+from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.common.Tools import Tools
 from SeasObjects.rdf.Resource import Resource
 
@@ -10,7 +10,7 @@ class AliveRequest(Request):
 	
 	def __init__(self, uri = None):
 		Request.__init__(self, uri)
-		self.setType(CLASS.SEAS_ALIVEREQUEST)
+		self.setType(RESOURCE.SEAS_ALIVEREQUEST)
 	
 	def serialize(self, model):
 		request = super(AliveRequest, self).serialize(model)
@@ -37,6 +37,6 @@ class AliveRequest(Request):
 
 	def fromString(self, data, serialization):
 		m = Tools().fromString(data, serialization)
-		res = Tools().getResourceByType(CLASS.SEAS_ALIVEREQUEST, m)
+		res = Tools().getResourceByType(RESOURCE.SEAS_ALIVEREQUEST, m)
 		return self.parse(res)
 		
\ No newline at end of file
