@@ -1,5 +1,5 @@
 from SeasObjects.common.PROPERTY import PROPERTY
-from SeasObjects.common.CLASS import CLASS
+from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.common.Tools import Tools
 from SeasObjects.rdf.Resource import Resource
 from SeasObjects.model.Response import Response
@@ -11,11 +11,11 @@ class AliveResponse(Response):
 	
 	def __init__(self, uri = None):
 		Response.__init__(self, uri)
-		self.setType(CLASS.SEAS_ALIVERESPONSE)
+		self.setType(RESOURCE.SEAS_ALIVERESPONSE)
 	
 	def fromString(self, data, serialization):
 		try:
-			return AliveResponse().parse(Tools().getResourceByType(CLASS.SEAS_ALIVERESPONSE, Tools().fromString(data, serialization)))
+			return AliveResponse().parse(Tools().getResourceByType(RESOURCE.SEAS_ALIVERESPONSE, Tools().fromString(data, serialization)))
  		except:
 			print "Unable to parse AliveResponse from the given string."
 			traceback.print_exc() 
