@@ -1,4 +1,4 @@
-from SeasObjects.common.CLASS import CLASS
+from SeasObjects.common.RESOURCE import RESOURCE
 
 from SeasObjects.model.Ability import Ability
 from SeasObjects.rdf.Resource import Resource
@@ -7,7 +7,7 @@ class Availability(Ability):
 
 	def __init__(self, uri = None):
 		Ability.__init__(self, uri)
-		self.setType(CLASS.SEAS_AVAILABILITY);
+		self.setType(RESOURCE.SEAS_AVAILABILITY);
 		
 	def parse(self, resource):
 		if isinstance(resource, Resource):
