@@ -4,7 +4,7 @@ class Controllability(Ability):
 
 	def __init__(self, uri = None):
 		Ability.__init__(self, uri)
-		self.setType(CLASS.SEAS_CONTROLLABILITY)
+		self.setType(RESOURCE.SEAS_CONTROLLABILITY)
 
 	def parse(resource):
 		if not resource.isAnon():
