@@ -1,7 +1,7 @@
 from SeasObjects.model.Evaluation import Evaluation
 from SeasObjects.rdf.Resource import Resource
 from SeasObjects.rdf.Statement import Statement
-from SeasObjects.common.CLASS import CLASS
+from SeasObjects.common.RESOURCE import RESOURCE
 
 class Input(Evaluation):
 	TYPE_DATA = 0
@@ -10,7 +10,7 @@ class Input(Evaluation):
 	def __init__(self, inputType = 0, uri = None):
 		Evaluation.__init__(self, uri)
 		self.inputType = inputType;
-		self.setType(CLASS.SEAS_INPUT)
+		self.setType(RESOURCE.SEAS_INPUT)
 	
 	def serialize(self, model):
 		return super(Input, self).serialize(model)
