@@ -1,5 +1,5 @@
 from SeasObjects.common.PROPERTY import PROPERTY
-from SeasObjects.common.CLASS import CLASS
+from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.common.Tools import Tools
 from SeasObjects.rdf.Resource import Resource
 from SeasObjects.model.Message import Message
@@ -11,14 +11,14 @@ class Notification(Message):
 
 	def __init__(self, uri = None):
 		Message.__init__(self, uri)
-		self.setType(CLASS.SEAS_NOTIFICATION)
+		self.setType(RESOURCE.SEAS_NOTIFICATION)
 			
 	def serialize(self, model):
 		return super(Notification, self).serialize(model)
 
 	def fromString(self, data, serialization):
 		try:
-			return Notification.parse(Tools().getResourceByType(CLASS.SEAS_NOTIFICATION, Tools().fromString(data, serialization)))
+			return Notification.parse(Tools().getResourceByType(RESOURCE.SEAS_NOTIFICATION, Tools().fromString(data, serialization)))
 		except:
 			print "Unable to parse Notification from the given string."
 			traceback.print_exc()
