@@ -1,4 +1,4 @@
-from SeasObjects.common.CLASS import CLASS
+from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.common.PROPERTY import PROPERTY
 from SeasObjects.common.Tools import Tools
 
@@ -13,7 +13,7 @@ class Request(Message):
 
 	def __init__(self, uri = None):
 		Message.__init__(self, uri)
-		self.setType(CLASS.SEAS_REQUEST)
+		self.setType(RESOURCE.SEAS_REQUEST)
 		
 	def serialize(self, model):
 		r = super(Request, self).serialize(model)
@@ -21,7 +21,7 @@ class Request(Message):
 	
 	def fromString(self, data, serialization):
 		try:
-			return Request.parse(Tools().getResourceByType(CLASS.SEAS_REQUEST, Tools().fromString(data, serialization)));
+			return Request.parse(Tools().getResourceByType(RESOURCE.SEAS_REQUEST, Tools().fromString(data, serialization)));
 		except:
 			print "Unable to parse Request from the given string."
 			traceback.print_exc() 
