@@ -1,4 +1,4 @@
-from SeasObjects.common.CLASS import CLASS
+from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.common.PROPERTY import PROPERTY
 from SeasObjects.common.Tools import Tools
 
@@ -9,7 +9,7 @@ class Response(Message):
 	
 	def __init__(self, uri = None):
 		Message.__init__(self, uri)
-		self.setType(CLASS.SEAS_RESPONSE)
+		self.setType(RESOURCE.SEAS_RESPONSE)
 
 	def serialize(self, model):
 		resource = super(Response, self).serialize(model)
@@ -18,7 +18,7 @@ class Response(Message):
 
 	def fromString(self, data, serialization):
 		try:
-			return self.parse(Tools().getResourceByType(CLASS.SEAS_RESPONSE, Tools().fromString(data, serialization)))
+			return self.parse(Tools().getResourceByType(RESOURCE.SEAS_RESPONSE, Tools().fromString(data, serialization)))
 		except:
 			print "Unable to parse Response from the given string."
 			traceback.print_exc() 
