@@ -1,4 +1,4 @@
-from SeasObjects.common.CLASS import CLASS
+from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.model.ServiceProvider import ServiceProvider
 
 
@@ -6,7 +6,7 @@ class WeatherServiceProvider(ServiceProvider):
 
 	def __init__(self, uri = None):
 		ServiceProvider.__init__(self)
-		self.addType(CLASS.SEAS_WEATHERSERVICEPROVIDER);
+		self.addType(RESOURCE.SEAS_WEATHERSERVICEPROVIDER);
 		self.setSeasIdentifierUri(uri);
 		
 
